'use strict';

var _yargs = require('yargs');

var _yargs2 = _interopRequireDefault(_yargs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _ncp = require('ncp');

var _ncp2 = _interopRequireDefault(_ncp);

var _opn = require('opn');

var _opn2 = _interopRequireDefault(_opn);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _package = require('../package.json');

var _package2 = _interopRequireDefault(_package);

var _index = require('./index');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var argv = _yargs2.default.usage('Usage: $0 [...options]').options({
    init: {
        type: 'string',
        description: 'Initialize a sample project'
    },
    port: {
        default: 3030,
        description: 'Port to listen on'
    },
    run: {
        alias: 'r',
        type: 'string',
        description: 'Script to run in browser'
    },
    watch: {
        alias: 'w',
        type: 'array',
        description: 'Scripts to watch for changes'
    },
    bundle: {
        alias: 'b',
        type: 'array',
        description: 'Scripts to bundle'
    },
    html: {
        type: 'string',
        description: 'Name of the input file for sharable HTML bundle'
    },
    js: {
        type: 'string',
        description: 'Name of the JavaScript file to include in the HTML bundle when no HTML is specified'
    },
    output: {
        alias: 'o',
        type: 'string',
        description: 'Name of the output file'
    },
    production: {
        type: 'boolean',
        default: false,
        description: 'Optimize bundle for production'
    },
    sourcemaps: {
        type: 'boolean',
        default: true,
        description: 'Generate sourcemaps for bundle'
    }
}).example('$0 --run index.js', 'Run the script \'index.js\' in a browser and watch for changes').example('$0 --port 8008 --watch index.js', 'Start the server in the port \'8008\' and watch \'index.js\' for changes').example('$0 --bundle entry.js --output bundle.js --production', 'Generate a bundle named \'bundle.js\' from \'entry.js\' for production').example('$0 --html index.html --output bundle.html', 'Generate a sharable HTML file named \'bundle.html\' from \'index.html\'').help('help').version(_package2.default.version).strict().argv;

if (argv.init) {
    var name = argv.init;

    if (typeof name !== 'string') {
        console.log('Please specify a name for the project!');
        process.exit(1);
    }

    if (_fs2.default.existsSync(_path2.default.join(process.cwd(), name))) {
        console.log('A folder named \'' + name + '\' already exits!');
        process.exit(1);
    }

    _ncp2.default.ncp(_path2.default.join(__dirname, '../template/'), _path2.default.join(process.cwd(), name), function (err) {
        if (err) {
            console.error(err);
            process.exit(1);
        }

        console.log('Project initialized successfully!');
    });
} else if (argv.bundle) {
    (0, _index.bundle)({
        root: process.cwd(),
        entry: argv.bundle.map(function (it) {
            return './' + it;
        }),
        output: argv.output,
        production: argv.production,
        sourcemaps: argv.sourcemaps
    }).then(function (result) {
        var assets = result.assetsByChunkName;
        var bundles = [];

        for (var b in assets) {
            var entry = assets[b];

            bundles.push(_path2.default.resolve(process.cwd(), Array.isArray(entry) ? entry[0] : entry));
        }

        console.log('Bundle' + (bundles.length > 1 ? 's' : '') + ' generated at ' + bundles.map(function (b) {
            return _chalk2.default.green(b);
        }).join(', '));
    }).catch(function (err) {
        console.error(err);
        process.exit(1);
    });
} else if (typeof argv.html === 'string') {
    (0, _index.html)({
        root: process.cwd(),
        js: argv.js,
        entry: argv.html,
        output: argv.output,
        production: argv.production,
        sourcemaps: argv.sourcemaps
    }).then(function (file) {
        console.log('Sharable HTML generated at ' + _chalk2.default.green(file));
    }).catch(function (err) {
        console.error(err);
        process.exit(1);
    });
} else {
    (0, _index.server)({
        root: process.cwd(),
        port: argv.port,
        run: argv.run,
        watch: argv.watch
    }).listen(argv.port);

    var url = 'http://localhost:' + argv.port;

    console.log('Quik is serving files at ' + _chalk2.default.blue(url));
    (0, _opn2.default)(url);
}
//# sourceMappingURL=quik-cli.js.map